import React from 'react';
import { Column, ColumnDef, SortingState, useReactTable, ColumnPinningState, RowSelectionState, OnChangeFn, PaginationState, ColumnFiltersState } from '@tanstack/react-table';
import { TableColor } from './DataTable.helpers';
import { ContainerCellProps } from './components/MainBody/MainBody';
declare module '@tanstack/react-table' {
    interface ColumnMeta<TData, TValue> {
        containerCell?: React.ComponentType<ContainerCellProps>;
        filterComponent?: React.ComponentType<{
            column: Column<TData, TValue>;
        }>;
        filterType?: string;
        customWidth?: number;
        noCellPadding?: boolean;
        actions?: any[];
    }
}
export interface DataTableProps<TData, TValue> {
    columns?: ColumnDef<TData, TValue>[];
    data?: TData[];
    columnPinning?: ColumnPinningState;
    columnVisibility?: {
        [key: string]: boolean;
    };
    enableHorizontalBorders?: boolean;
    getRowId?: (row: TData) => string;
    getSubRows?: ((originalRow: TData, index: number) => TData[] | undefined) | undefined;
    isColumnResizable?: boolean;
    isHeaderSticky?: boolean;
    color?: TableColor;
    pageIndex?: number;
    pageSize?: number;
    rowSelectionState?: RowSelectionState;
    sorting?: SortingState;
    onSortingChange?: (sorting: SortingState) => void;
    onRowSelectionChange?: OnChangeFn<RowSelectionState>;
    pagination?: PaginationState;
    onPaginationChange?: OnChangeFn<PaginationState>;
    globalFilter?: string;
    onGlobalFilterChange?: OnChangeFn<string>;
    onTableInstanceChange?: (table: ReturnType<typeof useReactTable<TData>>) => void;
    onColumnFiltersChange?: OnChangeFn<ColumnFiltersState>;
    tableInstance?: ReturnType<typeof useReactTable<TData>>;
    tableContainerStyle?: React.CSSProperties;
    hasDraggableRows?: boolean;
    shadowDepth?: 'none' | '100' | '200' | '300' | '400' | '500';
    draggableRowsProps?: {
        sensors?: any[];
        onDragEnd: (event: any) => void;
        items: string[];
    };
}
declare const DataTable: <TData, TValue>({ columns, data, columnPinning, columnVisibility, enableHorizontalBorders, isColumnResizable, isHeaderSticky, color, getRowId, getSubRows, sorting: controlledSorting, onSortingChange, onRowSelectionChange, rowSelectionState, pagination: controlledPagination, pageIndex, pageSize, onPaginationChange, globalFilter: controlledGlobalFilter, onGlobalFilterChange, onColumnFiltersChange, onTableInstanceChange, tableInstance, tableContainerStyle, hasDraggableRows, shadowDepth, draggableRowsProps }: DataTableProps<TData, TValue>) => React.JSX.Element;
export default DataTable;
